#
# spec file for package meson
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   mesonbuild
Name:           meson
Version:        0.40.1
Release:        0
Summary:        Python-based build system
License:        Apache-2.0
Group:          Development/Tools/Building
Url:            http://mesonbuild.com/
Source:         https://github.com/%{_name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/%{_name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
# PATCH-FIX-OPENSUSE meson-suse-ify-macros.patch dimstar@opensuse.org -- Make the macros non-RedHat specific: so far there are no separate {C,CXX,F}FLAGS.
Patch0:         meson-suse-ify-macros.patch
# PATCH-FIX-OPENSUSE meson-fix-gcc48.patch sor.alexei@meowr.ru -- Fix GCC 4.8 handling for openSUSE Leap 42.x.
Patch1:         meson-fix-gcc48.patch
# PATCH-FIX-UPSTREAM meson-disable-untested-code.patch gh#mesonbuild/meson#1480 dimstar@opensuse.org -- Do not assume that the untested meson test works with glib 2.52.0
Patch2:         meson-disable-untested-code.patch
# PATCH-FIX-UPSTREAM meson-handle-skipped-tests.patch gh#mesonbuild/meson#1804 dimstar@opensuse.org -- Actually do skip tests that are marked as MESON_SKIP_TEST
Patch3:         meson-handle-skipped-tests.patch
BuildRequires:  bison
BuildRequires:  boost-devel
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gcc-obj-c++
BuildRequires:  gcc-objc
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  gtk-doc
BuildRequires:  itstool
BuildRequires:  java-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  mono-core
BuildRequires:  mono-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python3 >= 3.4
BuildRequires:  python3-devel
BuildRequires:  python3-gobject
BuildRequires:  python3-setuptools
BuildRequires:  vala
BuildRequires:  wxWidgets-devel >= 3.0.0
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(zlib)
Requires:       ninja
# meson-gui was last used in openSUSE Leap 42.1.
Provides:       %{name}-gui = %{version}
Obsoletes:      %{name}-gui < %{version}
BuildArch:      noarch

%description
Meson is a build system designed to optimise programmer productivity.
It aims to do this by providing support for software development
tools and practices, such as unit tests, coverage reports, Valgrind,
CCache and the like. Supported languages include C, C++, Fortran,
Java, Rust. Build definitions are written in a non-turing complete
Domain Specific Language.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Lack of gtest, gmock, gnustep.
rm -rf "test cases/frameworks/2 gtest" \
  "test cases/frameworks/3 gmock/"     \
  "test cases/objc/2 nsstring"

%build
python3 setup.py build

%install
python3 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

install -Dpm 0644 data/macros.%{name} \
  %{buildroot}%{_rpmconfigdir}/macros.d/macros.%{name}

%check
export MESON_PRINT_TEST_OUTPUT=1
export SUSE_ASNEEDED=0
python3 run_tests.py

%files
%defattr(-,root,root)
%doc authors.txt contributing.txt COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}conf
%{_bindir}/%{name}introspect
%{_bindir}/%{name}test
%{_bindir}/wraptool
%{python3_sitelib}/%{_name}/
%{python3_sitelib}/%{name}-*
%{_rpmconfigdir}/macros.d/macros.%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}conf.1%{?ext_man}
%{_mandir}/man1/%{name}introspect.1%{?ext_man}
%{_mandir}/man1/%{name}test.1%{?ext_man}
%{_mandir}/man1/wraptool.1%{?ext_man}

%changelog
